@@ -3,11 +3,13 @@ DEFAULTS = {
     "ignore_missing": "",
     "ignore_transitive": "",
     "ignore_misplaced_dev": "",
-    "exclude": ".venv,tests",
+    "exclude": "venv,.venv,tests,setup.py",
     "extend_exclude": "",
     "ignore_notebooks": False,
     "skip_obsolete": False,
     "skip_missing": False,
     "skip_transitive": False,
     "skip_misplaced_dev": False,
+    "requirements_txt": "requirements.txt",
+    "requirements_txt_dev": "dev-requirements.txt,requirements-dev.txt",
 }
